import React, {useEffect, useState} from 'react';
import {getShortenLink, handleOriginalUrl} from './features/links/linkSlice';
import {useAppDispatch, useAppSelector} from './hooks';
import ILinkDTO from './types/ILinkDTO';

const App = () => {
  const {shortUrl} = useAppSelector((state) => state.links.link);
  const [linkState, setlinkState] = useState<string>('');
  const dispatch = useAppDispatch();

  const handleInput = (e: React.ChangeEvent<HTMLInputElement>) => {
    setlinkState(e.target.value);
    dispatch(handleOriginalUrl(linkState));
  };

  const handleSubmit = (e: React.ChangeEvent<HTMLFormElement>) => {
    e.preventDefault();
    const link: ILinkDTO = {
      originalUrl: linkState,
    };
    dispatch(getShortenLink(link));
  };

  useEffect(() => {}, [shortUrl]);

  return (
    <>
      <form onSubmit={handleSubmit}>
        <h1>Shorten your url</h1>
        <input onChange={handleInput} type="text" />
        <button type="submit">Shorten</button>
      </form>
      {shortUrl && (
        <>
          <h1>Your link now looks like this:</h1>
          <a target="_blank" href={shortUrl}>
            {shortUrl}
          </a>
        </>
      )}
    </>
  );
};

export default App;
